summaryrefslogtreecommitdiff
path: root/lisp/mh-e
diff options
context:
space:
mode:
authorGlenn Morris <rgm@gnu.org>2019-02-20 12:07:22 -0800
committerGlenn Morris <rgm@gnu.org>2019-02-20 12:07:22 -0800
commit83a9133e35827c1edbd8bf24a17ffa3b4bfb7be3 (patch)
tree11d2812db4a9ee4e66976b3a5f1e5ecbe52b4955 /lisp/mh-e
parentae77728d14e58054bdaee3c6965979947c778208 (diff)
parentff9c9620794e5fe5692cfd3badd207aac78921cb (diff)
downloademacs-83a9133e35827c1edbd8bf24a17ffa3b4bfb7be3.tar.gz
Merge from origin/emacs-26
ff9c962 ; * lisp/ldefs-boot.el: Update. b4a251c * ; ChangeLog.3 update d3104e3 * etc/AUTHORS: Update. a19bfb7 Remove .art from the default list of ImageMagick extensions 6985caa Fix input after setting x-wait-for-event-timeout nil 715388a Fix two warnings in eshell.texi d49cdd9 * lisp/minibuffer.el (completion-table-dynamic): Improve docs... 5dc4e51 * lisp/emacs-lisp/debug.el (debug-on-variable-change): Doc fi... 76ef805 Fix a typo in ELisp manual b5e66f4 Update citations of Internet RFCs 57ece2a Fix handling of manpage references divided by hyphenation 7ad0cd6 * doc/misc/eshell.texi: Fix some @ref's. 12b7940 Fix a typo in lispref/syntax.texi # Conflicts: # lisp/gnus/nnrss.el # lisp/mail/ietf-drums.el
Diffstat (limited to 'lisp/mh-e')
-rw-r--r--lisp/mh-e/mh-e.el18
-rw-r--r--lisp/mh-e/mh-utils.el4
2 files changed, 11 insertions, 11 deletions
diff --git a/lisp/mh-e/mh-utils.el b/lisp/mh-e/mh-utils.el
index 9526338b8ff..cad62787190 100644
--- a/lisp/mh-e/mh-utils.el
+++ b/lisp/mh-e/mh-utils.el
@@ -888,7 +888,7 @@ in this situation."
;;;###mh-autoload
(defun mh-header-field-beginning ()
"Move to the beginning of the current header field.
-Handles RFC 822 continuation lines."
+Handle RFC 822 (or later) continuation lines."
(beginning-of-line)
(while (looking-at "^[ \t]")
(forward-line -1)))
@@ -896,7 +896,7 @@ Handles RFC 822 continuation lines."
;;;###mh-autoload
(defun mh-header-field-end ()
"Move to the end of the current header field.
-Handles RFC 822 continuation lines."
+Handle RFC 822 (or later) continuation lines."
(forward-line 1)
(while (looking-at "^[ \t]")
(forward-line 1))
diff --git a/lisp/mh-e/mh-e.el b/lisp/mh-e/mh-e.el
index 3ff7765f395..bc09764656b 100644
--- a/lisp/mh-e/mh-e.el
+++ b/lisp/mh-e/mh-e.el
@@ -2420,14 +2420,14 @@ of citations entirely, choose \"None\"."
:package-version '(MH-E . "8.0"))
;; These entries have been intentionally excluded by the developers.
;; "Comments:" ; RFC 2822 - show this one
;; "Fax:" ; http://people.dsv.su.se/~jpalme/ietf/mail-headers/
;; "Mail-System-Version:" ; http://people.dsv.su.se/~jpalme/ietf/mail-headers/
;; "Mailer:" ; http://people.dsv.su.se/~jpalme/ietf/mail-headers/
;; "Organization:" ;
;; "Phone:" ; http://people.dsv.su.se/~jpalme/ietf/mail-headers/
;; "Reply-By:" ; RFC 2156
-;; "Reply-To:" ; RFC 2822
+;; "Reply-To:" ; RFC 822 (or later)
;; "Sender:" ;
;; "User-Agent:" ; Similar to X-Mailer, so display it.
;; "X-Mailer:" ;
@@ -2488,9 +2488,9 @@ of citations entirely, choose \"None\"."
"From " ; sendmail
"Generate-Delivery-Report:" ; RFC 2156
"Importance:" ; RFC 2156, 2421
- "In-Reply-To:" ; RFC 2822
+ "In-Reply-To:" ; RFC 822 (or later)
"Incomplete-Copy:" ; RFC 2156
- "Keywords:" ; RFC 2822
+ "Keywords:" ; RFC 822 (or later)
"Language:" ; RFC 2156
"Lines:" ; RFC 1036
"List-" ; RFC 2369, 2919
@@ -2500,7 +2500,7 @@ of citations entirely, choose \"None\"."
"Mail-Reply-To:" ; http://people.dsv.su.se/~jpalme/ietf/mail-headers/
"Mailing-List:" ; Egroups/yahoogroups mailing list manager
"Message-Content:" ; http://people.dsv.su.se/~jpalme/ietf/mail-headers/
- "Message-Id:" ; RFC 822
+ "Message-ID:" ; RFC 822 (or later)
"Message-Type:" ; RFC 2156
"Mime-Version" ; RFC 2045
"Msgid:"
@@ -2531,14 +2531,14 @@ of citations entirely, choose \"None\"."
"Priority:" ; RFC 2156
"Read-Receipt-To:" ; http://people.dsv.su.se/~jpalme/ietf/mail-headers/
"Received-SPF:" ; Gmail
- "Received:" ; RFC 822
- "References:" ; RFC 2822
+ "Received:" ; RFC 822 (or later)
+ "References:" ; RFC 822 (or later)
"Registered-Mail-Reply-Requested-By:" ; http://people.dsv.su.se/~jpalme/ietf/mail-headers/
"Remailed-" ; MH
"Replaces:" ; http://people.dsv.su.se/~jpalme/ietf/mail-headers/
"Replied:" ; MH
- "Resent-" ; RFC 2822
- "Return-Path:" ; RFC 822
+ "Resent-" ; RFC 822 (or later)
+ "Return-Path:" ; RFC 822 (or later)
"Return-Receipt-Requested:" ; http://people.dsv.su.se/~jpalme/ietf/mail-headers/
"Return-Receipt-To:" ; http://people.dsv.su.se/~jpalme/ietf/mail-headers/
"Seal-Send-Time:"
@@ -2420,14 +2420,14 @@ of citations entirely, choose \"None\"."
:package-version '(MH-E . "8.0"))
;; These entries have been intentionally excluded by the developers.
-;; "Comments:" ; RFC 2822 - show this one
+;; "Comments:" ; RFC 822 (or later) - show this one
;; "Fax:" ; http://people.dsv.su.se/~jpalme/ietf/mail-headers/
;; "Mail-System-Version:" ; http://people.dsv.su.se/~jpalme/ietf/mail-headers/